/*
 * FILE --- plant_sim.cc
 *
 * PURPOSE --- Source file for a class that provides a simulation of an 
 * example plant whose state is to be observed using the Linear State 
 * Observer utility for Single-Input-Single-Output (SISO) plants.
 * In actual implementations the signal generated from this example will
 * be measured from actual systems.
 *
 */

// Include Files
#include "plant_sim.hh"

PLANT_SIM::PLANT_SIM (double _sampling_period,
		      double _initial_time, 
		      double *_initial_state) 
  : RK4_SIM(2, 1, _sampling_period, _initial_time, _initial_state)
{
  // samp_period >= integration_step
  
  // Initialize parameters
  sampling_period = _sampling_period;
  a11 =  2.0; a12 = 1.0;
  a21 = -1.0; a22 = 1.0;
  
  b1 = 1.0;
  b2 = 2.0;
  
  c1 = 1.0; c2 = 1.0;
}

PLANT_SIM::~PLANT_SIM()
{
  
}

inline void PLANT_SIM::DERIV(const double t, const double *x, 
			     const double *u, double *xdot)
{
  // This is where the derivative is defined: xdot = f(t,x,u)
  
  // Simple plant dynamics
  xdot[0] = a11*x[0] + a12*x[1] + b1*u[0];
  xdot[1] = a21*x[0] + a22*x[1] + b2*u[0];
}

void PLANT_SIM::simulate()
{
  // Simulate the plant dynamics one step
  solve();
  
  // Calculate the plant output
  plant_output = c1*plant_state[0] + c2*plant_state[1];
}


